@@ -1,7 +1,14 @@
 from . import architectures
 from . import callbacks
 from . import objectives
-from ._discriminative import DCCA, DCCA_NOI, BarlowTwins, DCCA_SDL, DTCCA
+from ._discriminative import (
+    DCCA,
+    DCCA_NOI,
+    BarlowTwins,
+    DCCA_SDL,
+    DTCCA,
+    DCCA_EigenGame,
+)
 from ._generative import DVCCA, SplitAE, DCCAE
 
 __all__ = [
@@ -12,6 +19,7 @@ __all__ = [
     "DVCCA",
     "BarlowTwins",
     "DTCCA",
+    "DCCA_EigenGame",
     "SplitAE",
     "architectures",
     "objectives",
@@ -27,4 +35,5 @@ classes = [
     "BarlowTwins",
     "DTCCA",
     "SplitAE",
+    "DCCA_EigenGame",
 ]
