@@ -2,9 +2,9 @@ from typing import Union, Iterable
 
 import numpy as np
 
-from cca_zoo.models._iterative.utils import _delta_search, support_threshold
+from cca_zoo.models._iterative._base import _BaseIterative
+from cca_zoo.models._search import _delta_search, support_threshold
 from cca_zoo.utils import _process_parameter
-from ._base import _BaseInnerLoop, _BaseIterative
 
 
 class SCCA_Span(_BaseIterative):
@@ -31,27 +31,27 @@ class SCCA_Span(_BaseIterative):
     >>> rng=np.random.RandomState(0)
     >>> X1 = rng.random((10,5))
     >>> X2 = rng.random((10,5))
-    >>> model = SCCA_Span(regularisation="l0", c=[2, 2])
+    >>> model = SCCA_Span(regularisation="l0", tau=[2, 2])
     >>> model.fit((X1,X2)).score((X1,X2))
     array([0.84556666])
     """
 
     def __init__(
-            self,
-            latent_dims: int = 1,
-            scale: bool = True,
-            centre=True,
-            copy_data=True,
-            max_iter: int = 100,
-            initialization: str = "uniform",
-            tol: float = 1e-9,
-            regularisation="l0",
-            c: Union[Iterable[Union[float, int]], Union[float, int]] = None,
-            rank=1,
-            positive: Union[Iterable[bool], bool] = None,
-            random_state=None,
-            deflation="cca",
-            verbose=0,
+        self,
+        latent_dims: int = 1,
+        scale: bool = True,
+        centre=True,
+        copy_data=True,
+        max_iter: int = 100,
+        initialization: str = "uniform",
+        tol: float = 1e-3,
+        regularisation="l0",
+        tau: Union[Iterable[Union[float, int]], Union[float, int]] = None,
+        rank=1,
+        positive: Union[Iterable[bool], bool] = None,
+        random_state=None,
+        deflation="cca",
+        verbose=0,
     ):
         super().__init__(
             latent_dims=latent_dims,
@@ -65,23 +65,11 @@ class SCCA_Span(_BaseIterative):
             deflation=deflation,
             verbose=verbose,
         )
-        self.c = c
+        self.tau = tau
         self.regularisation = regularisation
         self.rank = rank
         self.positive = positive
 
-    def _set_loop_params(self):
-        self.loop = _SpanCCAInnerLoop(
-            self.update,
-            max_iter=self.max_iter,
-            c=self.c,
-            tol=self.tol,
-            rank=self.rank,
-            random_state=self.random_state,
-            positive=self.positive,
-            verbose=self.verbose,
-        )
-
     def _check_params(self):
         """check number of views=2"""
         if self.n_views != 2:
@@ -89,35 +77,14 @@ class SCCA_Span(_BaseIterative):
         self.max_obj = 0
         if self.regularisation == "l0":
             self.update = support_threshold
-            self.c = _process_parameter("c", self.c, 0, self.n_views)
+            self.tau = _process_parameter("tau", self.tau, 0, self.n_views)
         elif self.regularisation == "l1":
             self.update = _delta_search
-            self.c = _process_parameter("c", self.c, 0, self.n_views)
+            self.tau = _process_parameter("tau", self.tau, 0, self.n_views)
         self.positive = _process_parameter(
             "positive", self.positive, False, self.n_views
         )
 
-
-class _SpanCCAInnerLoop(_BaseInnerLoop):
-    def __init__(
-            self,
-            update,
-            max_iter: int = 100,
-            tol=1e-9,
-            c=None,
-            rank=1,
-            random_state=None,
-            positive=False,
-            verbose=0,
-    ):
-        super().__init__(
-            max_iter=max_iter, tol=tol, random_state=random_state, verbose=verbose
-        )
-        self.update = update
-        self.c = c
-        self.rank = rank
-        self.positive = positive
-
     def _initialize(self, views):
         self.max_obj = 0
         cov = views[0].T @ views[1] / views[0].shape[0]
@@ -127,18 +94,19 @@ class _SpanCCAInnerLoop(_BaseInnerLoop):
         self.D = D[: self.rank]
         self.Q = Q[: self.rank, :].T
 
-    def _inner_iteration(self, views):
+    def _update(self, views, scores, weights):
         c = self.random_state.randn(self.rank)
         c /= np.linalg.norm(c)
         a = self.P @ np.diag(self.D) @ c
-        u = self.update(a, self.c[0])
+        u = self.update(a, self.tau[0])
         u /= np.linalg.norm(u)
         b = self.Q @ np.diag(self.D) @ self.P.T @ u
-        v = self.update(b, self.c[1])
+        v = self.update(b, self.tau[1])
         v /= np.linalg.norm(v)
         if b.T @ v > self.max_obj:
             self.max_obj = b.T @ v
-            self.scores[0] = views[0] @ u
-            self.scores[1] = views[1] @ v
-            self.weights[0] = u
-            self.weights[1] = v
+            scores[0] = views[0] @ u
+            scores[1] = views[1] @ v
+            weights[0] = u
+            weights[1] = v
+        return scores, weights
