@@ -77,11 +77,8 @@ class NCCA(_BaseCCA):
         return self
 
     def transform(self, views: Iterable[np.ndarray], **kwargs):
-        check_is_fitted(self, attributes=["f", "g"])
-        views = _check_views(
-            *views, copy=self.copy_data, accept_sparse=self.accept_sparse
-        )
-        views = self._centre_scale_transform(views)
+        _check_views(views)
+        views = [self.scalers[i].transform(view) for i, view in enumerate(views)]
         nns = [
             self.knns[i].kneighbors(view, self.nearest_neighbors[i])
             for i, view in enumerate(views)
