@@ -37,7 +37,6 @@ class _BaseStochastic(_BaseCCA):
         initialization: Union[str, callable] = "random",
         track_training=False,
         nesterov=True,
-        float32=True,
     ):
         if accept_sparse is None:
             accept_sparse = ["csc", "csr"]
@@ -65,6 +64,7 @@ class _BaseStochastic(_BaseCCA):
         self.initialization = initialization
         self.track_training = track_training
         self.nesterov = nesterov
+        self.dtypes = [np.float32]
 
     def fit(self, views: Iterable[np.ndarray], y=None, **kwargs):
         views = self._validate_inputs(views)
@@ -75,7 +75,7 @@ class _BaseStochastic(_BaseCCA):
             views, self.initialization, self.random_state, self.latent_dims
         )
         self.weights = initializer.fit(views).weights
-        self.weights=[weights.astype(np.float32) for weights in self.weights]
+        self.weights = [weights.astype(np.float32) for weights in self.weights]
         if self.nesterov:
             self.weights_old = self.weights.copy()
             self.lam = [0, 0]
@@ -85,17 +85,13 @@ class _BaseStochastic(_BaseCCA):
                 stop = self._update(sample["views"])
                 if self.nesterov:
                     self._step_lambda()
-                if self.batch_size is None:
-                    self.objective(sample["views"], weights=self.weights)
             if self.val_split is not None:
                 for i, sample in enumerate(val_dataloader):
                     self.track.append(
                         self.objective(sample["views"], weights=self.weights)
                     )
             else:
-                self.track.append(
-                    self.objective(views, weights=self.weights)
-                )
+                self.track.append(self.objective(views, weights=self.weights))
             if stop:
                 break
         return self
@@ -109,7 +105,9 @@ class _BaseStochastic(_BaseCCA):
             train_size = int((1 - self.val_split) * len(dataset))
             val_size = len(dataset) - train_size
             dataset, val_dataset = data.random_split(dataset, [train_size, val_size])
-            sampler = BatchSampler(SequentialSampler(dataset), batch_size=len(val_dataset), drop_last=False)
+            sampler = BatchSampler(
+                SequentialSampler(dataset), batch_size=len(val_dataset), drop_last=False
+            )
             val_loader = DataLoader(
                 val_dataset,
                 sampler=sampler,
@@ -126,7 +124,9 @@ class _BaseStochastic(_BaseCCA):
             batch_size = len(dataset)
         else:
             batch_size = self.batch_size
-        sampler = BatchSampler(RandomSampler(dataset), batch_size=batch_size, drop_last=False)
+        sampler = BatchSampler(
+            RandomSampler(dataset), batch_size=batch_size, drop_last=False
+        )
         train_loader = DataLoader(
             dataset,
             sampler=sampler,
@@ -154,6 +154,7 @@ class _BaseStochastic(_BaseCCA):
     def objective(self, views, weights):
         raise NotImplementedError
 
+
 class BatchNumpyDataset(NumpyDataset):
     def __getitem__(self, index):
         if self.labels is not None:
@@ -161,6 +162,7 @@ class BatchNumpyDataset(NumpyDataset):
         else:
             return {"views": self.views}
 
+
 def tv(z):
     all_z = np.hstack(z)
     C = np.cov(all_z, rowvar=False)
@@ -170,4 +172,4 @@ def tv(z):
 
 
 def tcc(z):
-    return CCA(z[0].shape[1]).fit(z).score(z).sum()
\ No newline at end of file
+    return CCA(z[0].shape[1]).fit(z).score(z).sum()
