@@ -28,7 +28,7 @@ Y = rng.rand(256, 12)
 Z = rng.rand(256, 14)
 X_conv = rng.rand(256, 1, 16, 16)
 Y_conv = rng.rand(256, 1, 16, 16)
-dataset = NumpyDataset([X, Y, Z], scale=True, centre=True)
+dataset = NumpyDataset([X, Y, Z])
 check_dataset(dataset)
 train_dataset, val_dataset = random_split(dataset, [200, 56])
 loader = get_dataloaders(dataset)
