@@ -6,9 +6,11 @@ This example demonstrates how to easily train Deep CCA models and variants
 """
 
 import pytorch_lightning as pl
+
 from cca_zoo.deepmodels import (
     DCCA,
-    DTCCA, objectives,
+    DTCCA,
+    objectives,
 )
 from cca_zoo.deepmodels import architectures
 
@@ -27,7 +29,6 @@ train_loader, val_loader, train_labels = example_mnist_data(N_TRAIN, N_VAL)
 encoder_1 = architectures.Encoder(latent_dims=LATENT_DIMS, feature_size=392)
 encoder_2 = architectures.Encoder(latent_dims=LATENT_DIMS, feature_size=392)
 
-
 # %%
 # Deep MCCA
 # ----------
@@ -37,7 +38,6 @@ dcca = DCCA(
 trainer = pl.Trainer(max_epochs=EPOCHS, enable_checkpointing=False)
 trainer.fit(dcca, train_loader, val_loader)
 
-
 # %%
 # Deep GCCA
 # ---------
@@ -47,7 +47,6 @@ dcca = DCCA(
 trainer = pl.Trainer(max_epochs=EPOCHS, enable_checkpointing=False)
 trainer.fit(dcca, train_loader, val_loader)
 
-
 # %%
 # Deep TCCA
 # ---------
