@@ -5,16 +5,14 @@ Model Plotting
 This script will show how to use the plotting functions of the CCA-Zoo package.
 """
 
+import matplotlib.pyplot as plt
 import numpy as np
 from sklearn.model_selection import train_test_split
 
-from cca_zoo import CCA
+from cca_zoo.models import CCA
 from cca_zoo.data.simulated import LinearSimulatedData
-import matplotlib.pyplot as plt
-
 from cca_zoo.plotting import pairplot_train_test
 
-
 # Data
 # ------
 np.random.seed(42)
@@ -35,7 +33,7 @@ X_tr, X_te, Y_tr, Y_te = train_test_split(X, Y, test_size=0.2, random_state=42)
 
 cca = CCA(latent_dims=latent_dims).fit((X_tr, Y_tr))
 
-#%%
+# %%
 # Plotting
 # ---------
 
