@@ -6,11 +6,11 @@ This script will show how to use the model validation methods in CCA-Zoo includi
 permutation testing, learning curves, and cross-validation.
 """
 
+import matplotlib.pyplot as plt
 import numpy as np
 
-from cca_zoo import CCA, learning_curve
+from cca_zoo.models import CCA
 from cca_zoo.data.simulated import LinearSimulatedData
-import matplotlib.pyplot as plt
 
 # %%
 # Data
@@ -29,7 +29,7 @@ latent_dims = 3
 # Permutation Testing
 # -------------------
 
-from cca_zoo.model_selection import permutation_test_score
+from cca_zoo.model_selection import permutation_test_score, learning_curve
 from sklearn.model_selection import KFold, ShuffleSplit
 
 LATENT_DIMS = 3
